
#ifndef xxACTNAME_H
#define xxACTNAME_H

String strRegression("Regression");
String strClassification("Classification");


String strNormal("Normal");
String strLogistic("Logistic");
String strCauchy("Cauchy");
String strExponential("Exponential");

String strPoisson("Poisson");
String strGamma("Gamma");


String strSigmoid("Sigmoid");
String strRelu("Relu");
String strLeakyRelu("LeakyRelu");
String strTanH("TanH");
String strArcTan("ArcTan");
String strArcSinH("ArcSinH");
String strElliotSig("ElliotSig");
String strSoftPlus("SoftPlus");
String strBentIdentity("BentIdentity");
String strSinusoid("Sinusoid");
String strGaussian("Gaussian");
String strSinc("Sinc");
String strIdentity("Identity");



String strSGD("SGD");
String strMomentum("Momentum");
String strAdaGrad("AdaGrad");
String strNesterov("Nesterov");
String strRMSprop("RMSprop");
String strAdam("Adam");


#endif



















